@@ -2,6 +2,7 @@ package Benchmark::Perl::Formance::Plugin::DPath;
 BEGIN {
   $Benchmark::Perl::Formance::Plugin::DPath::AUTHORITY = 'cpan:SCHWIGON';
 }
+# ABSTRACT: benchmark plugin - DPath - stress lookup, traversing and copying data structures
 
 use strict;
 use warnings;
@@ -483,6 +484,7 @@ sub main {
                 dpath => run_dpath(),
                };
 }
+
 1;
 
 __END__
@@ -493,11 +495,7 @@ __END__
 
 =head1 NAME
 
-Benchmark::Perl::Formance::Plugin::DPath
-
-=head1 NAME
-
-Benchmark::Perl::Formance::Plugin::DPath - Use DPath to stress lookup, traversing and copying data structures
+Benchmark::Perl::Formance::Plugin::DPath - benchmark plugin - DPath - stress lookup, traversing and copying data structures
 
 =head1 AUTHOR
 
