@@ -2,6 +2,7 @@ package Benchmark::Perl::Formance::Plugin::FibOO;
 BEGIN {
   $Benchmark::Perl::Formance::Plugin::FibOO::AUTHORITY = 'cpan:SCHWIGON';
 }
+# ABSTRACT: benchmark plugin - FibOO - Stress recursion and method calls (plain OO)
 
 # Fibonacci numbers
 
@@ -63,11 +64,7 @@ __END__
 
 =head1 NAME
 
-Benchmark::Perl::Formance::Plugin::FibOO
-
-=head1 NAME
-
-Benchmark::Perl::Formance::Plugin::FibOO - Stress recursion and method calls (plain OO)
+Benchmark::Perl::Formance::Plugin::FibOO - benchmark plugin - FibOO - Stress recursion and method calls (plain OO)
 
 =head1 AUTHOR
 
